@@ -25,7 +25,7 @@ def differ():
 @differ.command()
 #@click.option("cassette_path", type=click.Path(exists=True))
 @click.argument("cassette_path", type=str)
-@click.option("--host", help="HOST.", required=False, type=str, default='')
+@click.option("--host", help="HOST.", required=False, type=str)
 @click.option("--protocol", help="protocol", required=False, type=str)
 @click.option("--diff", '-d',  help="Comparing new response with the old", required=False, type=bool)
 @click.option("--status", '-s',  help="Status code", required=False, type=int)
@@ -40,13 +40,11 @@ def run(cassette_path, status=None, host='', diff=False, config=None, custom_ser
     #click.secho(f"{bold('Total interactions')}: {len(cassette['interactions'])}\n")
     for replayed in replay(cassette_path=cassette_path, ignore_body=ignore_body, host=host, status=status, protocol=protocol, diff=diff):
 
-        pass
         click.secho(f"  {bold('ID')}              | {replayed.id}")
         click.secho(f"  {bold('URI')}             | {replayed.request.uri}")
-        if hasattr(replayed, 'response'):
+        if replayed.cass_response:
             click.secho(f"  {bold('Old status code')} | {replayed.cass_response['status']['code']}")
-        if hasattr(replayed, 'response'):
-            click.secho(f"  {bold('New status code')} | {replayed.response.status_code}")
+        click.secho(f"  {bold('New status code')} | {replayed.response.status_code}")
         #click.secho(f"  {bold('Old request')}     | {replayed.interaction['request']}")
         #if hasattr(replayed, 'response'):
         #    click.secho(f"  {bold('New request')}     | {replayed.response.request.body}\n")
